@@ -10,7 +10,7 @@ async def main() -> None:
     engine = XGATaskEngine(general_tools=["*"])
 
     user_input =  "This week's gold price"
-    final_result = await engine.run_task_with_final_answer(task_message={"role": "user", "content": user_input})
+    final_result = await engine.run_task_with_final_answer(task_input={"role": "user", "content": user_input})
     print("FINAL RESULT:", final_result)
 
 asyncio.run(main())
\ No newline at end of file
