@@ -25,7 +25,7 @@ async def main() -> None:
 
     user_input =  "locate fault and solution"
     final_result = await engine.run_task_with_final_answer(
-        task_message={"role": "user", "content": user_input},
+        task_input={"role": "user", "content": user_input},
         trace_id=trace_id
     )
     print("FINAL RESULT:", final_result)
@@ -34,7 +34,7 @@ async def main() -> None:
         print("====== Wait for user input ... ======")
         user_input = "ip=10.0.1.1"
         final_result = await engine.run_task_with_final_answer(
-            task_message={"role": "user", "content": user_input},
+            task_input={"role": "user", "content": user_input},
             trace_id=trace_id
         )
         print("FINAL RESULT:", final_result)
