@@ -10,7 +10,7 @@ async def main() -> None:
     engine =  XGATaskEngine()
 
     final_result = await engine.run_task_with_final_answer(
-        task_message={"role": "user", "content": "1+7"}
+        task_input={"role": "user", "content": "1+7"}
     )
 
     print("FINAL RESULT:", final_result)
