@@ -376,19 +376,31 @@ class TaskResponseProcessor(ABC):
         logging.info(f"TaskProcessor execute_tools_in_parallel: Execution completed for {len(results)} tools, total {tool_num} tools)")
         return processed_results
 
+    def _create_tool_context(self,
+                             tool_call: Dict[str, Any],
+                             tool_index: int,
+                             assistant_message_id: Optional[str] = None,
+                             parsing_details: Optional[Dict[str, Any]] = None,
+                             result: Optional[XGAToolResult] = None,
+                             ) -> ToolExecutionContext:
+        """Create a tool execution context with display name and parsing details populated."""
+        return ToolExecutionContext(
+            tool_call               = tool_call,
+            tool_index              = tool_index,
+            function_name           = tool_call['function_name'],
+            xml_tag_name            = tool_call['xml_tag_name'],
+            assistant_message_id    = assistant_message_id,
+            parsing_details         = parsing_details,
+            result                  = result
+        )
 
-    def _add_tool_messsage(self,
-                           tool_call: Dict[str, Any],
-                           result: XGAToolResult,
-                           strategy: XmlAddingStrategy = "assistant_message",
-                           assistant_message_id: Optional[str] = None,
-                           parsing_details: Optional[Dict[str, Any]] = None
-                           ) -> Optional[Dict[str, Any]]:  # Return the full message object
+
+    def _add_tool_messsage(self,context:ToolExecutionContext, strategy: XmlAddingStrategy) -> Optional[Dict[str, Any]]:  # Return the full message object
         # Create two versions of the structured result
         # Rich version for the frontend
-        result_for_frontend = self._create_structured_tool_result(tool_call, result, parsing_details, for_llm=False)
+        result_for_frontend = self._create_structured_tool_result(context.tool_call, context.result, context.parsing_details, for_llm=False)
         # Concise version for the LLM
-        result_for_llm = self._create_structured_tool_result(tool_call, result, parsing_details, for_llm=True)
+        result_for_llm = self._create_structured_tool_result(context.tool_call, context.result, context.parsing_details, for_llm=True)
 
         # Add the message with the appropriate role to the conversation history
         # This allows the LLM to see the tool result in subsequent interactions
@@ -399,11 +411,11 @@ class TaskResponseProcessor(ABC):
         }
 
         metadata = {}
-        if assistant_message_id:
-            metadata['assistant_message_id'] = assistant_message_id
+        if context.assistant_message_id:
+            metadata['assistant_message_id'] = context.assistant_message_id
 
-        if parsing_details:
-            metadata['parsing_details'] = parsing_details
+        if context.parsing_details:
+            metadata['parsing_details'] = context.parsing_details
 
         metadata['frontend_content'] = result_for_frontend
 
@@ -455,25 +467,6 @@ class TaskResponseProcessor(ABC):
         return structured_result
 
 
-    def _create_tool_context(self,
-                             tool_call: Dict[str, Any],
-                             tool_index: int,
-                             assistant_message_id: Optional[str] = None,
-                             parsing_details: Optional[Dict[str, Any]] = None,
-                             result: Optional[XGAToolResult] = None,
-                             ) -> ToolExecutionContext:
-        """Create a tool execution context with display name and parsing details populated."""
-        return ToolExecutionContext(
-            tool_call               = tool_call,
-            tool_index              = tool_index,
-            function_name           = tool_call['function_name'],
-            xml_tag_name            = tool_call['xml_tag_name'],
-            assistant_message_id    = assistant_message_id,
-            parsing_details         = parsing_details,
-            result                  = result
-        )
-
-
     def _add_tool_start_message(self, context: ToolExecutionContext) -> Optional[Dict[str, Any]]:
         """Formats, saves, and returns a tool started status message."""
         content = {
