@@ -17,8 +17,10 @@ from xgae.engine.responser.responser_base import TaskResponserContext, TaskRespo
 
 class XGATaskEngine:
     def __init__(self,
-                 session_id: Optional[str] = None,
                  task_id: Optional[str] = None,
+                 task_no: Optional[int] = None,
+                 session_id: Optional[str] = None,
+                 user_id: Optional[str] = None,
                  agent_id: Optional[str] = None,
                  general_tools: Optional[List[str]] = None,
                  custom_tools: Optional[List[str]] = None,
@@ -27,10 +29,12 @@ class XGATaskEngine:
                  tool_exec_parallel: Optional[bool] = None,
                  llm_config: Optional[LLMConfig] = None,
                  prompt_builder: Optional[XGAPromptBuilder] = None,
-                 tool_box: Optional[XGAToolBox] = None):
+                 tool_box: Optional[XGAToolBox] = None
+                 ):
         self.task_id    = task_id if task_id else f"xga_task_{uuid4()}"
-        self.agent_id   = agent_id
         self.session_id = session_id
+        self.user_id    = user_id
+        self.agent_id   = agent_id
 
         self.llm_client = LLMClient(llm_config)
         self.model_name = self.llm_client.model_name
@@ -48,7 +52,7 @@ class XGATaskEngine:
         self.use_assistant_chunk_msg = to_bool(os.getenv('USE_ASSISTANT_CHUNK_MSG', False))
         self.tool_exec_parallel = True if tool_exec_parallel is None else tool_exec_parallel
 
-        self.task_no = -1
+        self.task_no = (task_no - 1) if task_no  else -1
         self.task_run_id :str = None
         self.task_prompt :str = None
         self.task_langfuse: XGATaskLangFuse = None
@@ -56,16 +60,16 @@ class XGATaskEngine:
         self.task_response_msgs: List[XGAResponseMessage] = []
 
     async def run_task_with_final_answer(self,
-                                         task_message: Dict[str, Any],
+                                         task_input: Dict[str, Any],
                                          trace_id: Optional[str] = None) -> XGATaskResult:
-        final_result:XGATaskResult = None
+        final_result: XGATaskResult = None
         try:
             await self._init_task()
 
-            self.task_langfuse.start_root_span("run_task_with_final_answer", task_message, trace_id)
+            self.task_langfuse.start_root_span("run_task_with_final_answer", task_input, trace_id)
 
             chunks = []
-            async for chunk in self.run_task(task_message=task_message, trace_id=trace_id):
+            async for chunk in self.run_task(task_input, trace_id):
                 chunks.append(chunk)
 
             if len(chunks) > 0:
@@ -79,14 +83,14 @@ class XGATaskEngine:
 
 
     async def run_task(self,
-                       task_message: Dict[str, Any],
+                       task_input: Dict[str, Any],
                        trace_id: Optional[str] = None) -> AsyncGenerator[Dict[str, Any], None]:
         try:
             await self._init_task()
 
-            self.task_langfuse.start_root_span("run_task", task_message, trace_id)
+            self.task_langfuse.start_root_span("run_task", task_input, trace_id)
 
-            self.add_response_message(type="user", content=task_message, is_llm_message=True)
+            self.add_response_message(type="user", content=task_input, is_llm_message=True)
 
             async for chunk in self._run_task_auto():
                 yield chunk
@@ -114,10 +118,14 @@ class XGATaskEngine:
                 await  self.tool_box.load_mcp_tools_schema()
 
             await self.tool_box.creat_task_tool_box(self.task_id, general_tools, custom_tools)
-            general_tool_schemas = self.tool_box.get_task_tool_schemas(self.task_id, "general_tool")
-            custom_tool_schemas = self.tool_box.get_task_tool_schemas(self.task_id, "custom_tool")
+            general_tool_schemas = self.tool_box.get_task_tool_schemas(self.task_id, "general")
+            custom_tool_schemas = self.tool_box.get_task_tool_schemas(self.task_id, "custom")
+            agent_tool_schemas = self.tool_box.get_task_tool_schemas(self.task_id, "agent")
 
-            self.task_prompt = self.prompt_builder.build_task_prompt(self.model_name, general_tool_schemas, custom_tool_schemas)
+            self.task_prompt = self.prompt_builder.build_task_prompt(self.model_name,
+                                                                     general_tool_schemas,
+                                                                     custom_tool_schemas,
+                                                                     agent_tool_schemas)
 
             logging.info("*" * 10 + f"   XGATaskEngine Task'{self.task_id}' Initialized   " + "*" * 10)
             logging.info(f"model_name={self.model_name}, is_stream={self.is_stream}")
@@ -149,30 +157,30 @@ class XGATaskEngine:
                             status_content = chunk['content']
                             status_type = status_content['status_type']
                             if status_type == "error":
-                                logging.error(f"TaskEngine run_task_auto: task_response error: {chunk.get('message')}")
+                                logging.error(f"XGATaskEngine run_task_auto: task_response error: {chunk.get('message')}")
                                 auto_continue = False
                                 break
                             elif status_type == "finish":
                                 finish_reason = status_content['finish_reason']
                                 if finish_reason == "completed":
-                                    logging.info(f"TaskEngine run_task_auto: Detected finish_reason='completed', TASK_COMPLETE Success !")
+                                    logging.info(f"XGATaskEngine run_task_auto: Detected finish_reason='completed', TASK_COMPLETE Success !")
                                     auto_continue = False
                                     break
                                 elif finish_reason == "xml_tool_limit_reached":
-                                    logging.warning(f"TaskEngine run_task_auto: Detected finish_reason='xml_tool_limit_reached', stop auto-continue")
+                                    logging.warning(f"XGATaskEngine run_task_auto: Detected finish_reason='xml_tool_limit_reached', stop auto-continue")
                                     auto_continue = False
                                     break
                                 elif finish_reason == "non_tool_call":
-                                    logging.warning(f"TaskEngine run_task_auto: Detected finish_reason='non_tool_call', stop auto-continue")
+                                    logging.warning(f"XGATaskEngine run_task_auto: Detected finish_reason='non_tool_call', stop auto-continue")
                                     auto_continue = False
                                     break
                                 elif finish_reason in ["stop", "length"]: # 'length'  occur on some LLM
                                     auto_continue_count += 1
                                     auto_continue = True if auto_continue_count < self.max_auto_run else False
                                     update_continuous_state(auto_continue_count, auto_continue)
-                                    logging.info(f"TaskEngine run_task_auto: Detected finish_reason='{finish_reason}', auto-continuing ({auto_continue_count}/{self.max_auto_run})")
+                                    logging.info(f"XGATaskEngine run_task_auto: Detected finish_reason='{finish_reason}', auto-continuing ({auto_continue_count}/{self.max_auto_run})")
                     except Exception as parse_error:
-                        trace = log_trace(parse_error,f"TaskEngine run_task_auto: Parse chunk error, chunk: {chunk}")
+                        trace = log_trace(parse_error,f"XGATaskEngine run_task_auto: Parse chunk error, chunk: {chunk}")
                         self.task_langfuse.root_span.event(name="engine_parse_chunk_error", level="ERROR",
                                              status_message=f"Task Engine parse chunk error: {parse_error}",
                                              metadata={"content": chunk, "trace": trace})
@@ -181,7 +189,7 @@ class XGATaskEngine:
                         error_msg = self.add_response_message(type="status", content=status_content, is_llm_message=False)
                         yield error_msg
             except Exception as run_error:
-                trace = log_trace(run_error, "TaskEngine run_task_auto: Call task_run_once")
+                trace = log_trace(run_error, "XGATaskEngine run_task_auto: Call task_run_once")
                 self.task_langfuse.root_span.event(name="engine_task_run_once_error", level="ERROR",
                                                    status_message=f"Call task_run_once error: {run_error}",
                                                    metadata={"trace": trace})
@@ -207,7 +215,7 @@ class XGATaskEngine:
         auto_count = continuous_state.get("auto_continue_count")
         langfuse_metadata = self.task_langfuse.create_llm_langfuse_meta(auto_count)
 
-        llm_response = await self.llm_client.create_completion(llm_messages, langfuse_metadata)
+        llm_response = await self.llm_client.acompletion(llm_messages, langfuse_metadata)
         response_processor = self._create_response_processer()
 
         async for chunk in response_processor.process_response(llm_response, llm_messages, continuous_state):
@@ -267,7 +275,7 @@ class XGATaskEngine:
                 logging.warning(f"❌ FINAL_RESULT: LLM Result is EMPTY, finish_reason={finish_reason}")
                 final_result = XGATaskResult(type="error", content="LLM has no answer")
         except Exception as e:
-            trace = log_trace(e, f"TaskEngine parse_final_result: Parse message chunk error, chunk: {chunk}")
+            trace = log_trace(e, f"XGATaskEngine parse_final_result: Parse message chunk error, chunk: {chunk}")
             self.task_langfuse.root_span.event(name="engine_parse_final_result_error", level="ERROR",
                                                status_message=f"Task Engine parse final result error: {e}",
                                                metadata={"content": chunk, "trace": trace})
@@ -281,11 +289,12 @@ class XGATaskEngine:
                              is_llm_message: bool,
                              metadata: Optional[Dict[str, Any]]=None)-> XGAResponseMessage:
         metadata = metadata or {}
-        metadata["task_id"]     = self.task_id
-        metadata["task_run_id"] = self.task_run_id
-        metadata["trace_id"]    = self.task_langfuse.trace_id
-        metadata["session_id"]  = self.session_id
-        metadata["agent_id"]    = self.agent_id
+        metadata['task_id']     = self.task_id
+        metadata['task_run_id'] = self.task_run_id
+        metadata['trace_id']    = self.task_langfuse.trace_id
+        metadata['session_id']  = self.session_id
+        metadata['user_id']     = self.user_id
+        metadata['agent_id']    = self.agent_id
 
         message = XGAResponseMessage(
             message_id      = f"xga_msg_{uuid4()}",
@@ -308,7 +317,7 @@ class XGATaskEngine:
     def get_history_llm_messages (self) -> List[Dict[str, Any]]:
         llm_messages = []
         for message in self.task_response_msgs:
-            if message['is_llm_message']:
+            if message['is_llm_message'] and message['type'] != "assistant_chunk":
                 llm_messages.append(message)
 
         response_llm_contents = []
@@ -355,7 +364,14 @@ class XGATaskEngine:
 
 
     def _create_task_langfuse(self)-> XGATaskLangFuse:
-        return XGATaskLangFuse(self.session_id, self.task_id, self.task_run_id, self.task_no, self.agent_id)
+        return XGATaskLangFuse(
+            task_id      = self.task_id,
+            task_run_id  = self.task_run_id,
+            task_no      = self.task_no,
+            session_id   = self.session_id,
+            agent_id     = self.agent_id,
+            user_id      = self.user_id
+        )
 
 
     def _logging_reponse_chunk(self, chunk, auto_count: int)-> None:
@@ -380,11 +396,11 @@ class XGATaskEngine:
                 pretty_content = json.dumps(status_content, ensure_ascii=False, indent=2)
 
             if chunk_type == "assistant_chunk":
-                logging.debug(f"TASK_RESP_CHUNK[{auto_count}]<{chunk_type}{prefix}> content: {pretty_content}")
+                logging.debug(f"TASK_RESP_CHUNK[{self.task_no}]({auto_count})<{chunk_type}{prefix}> content: {pretty_content}")
             else:
-                logging.info(f"TASK_RESP_CHUNK[{auto_count}]<{chunk_type}{prefix}> content: {pretty_content}")
+                logging.info(f"TASK_RESP_CHUNK[{self.task_no}]({auto_count})<{chunk_type}{prefix}> content: {pretty_content}")
         except Exception as e:
-            logging.error(f"TaskEngine logging_reponse_chunk: Decorate chunk={chunk}, error: {e}")
+            logging.error(f"XGATaskEngine logging_reponse_chunk: Decorate chunk={chunk}, error: {e}")
 
 
 
@@ -406,7 +422,7 @@ if __name__ == "__main__":
                                 agent_id="agent_1"
                                 )
         user_input = "locate 10.0.0.1 fault and solution"
-        final_result = await engine.run_task_with_final_answer(task_message={'role': "user", 'content': user_input})
+        final_result = await engine.run_task_with_final_answer(task_input={'role': "user", 'content': user_input})
         print(f"FINAL RESULT:{final_result}")
 
 
